@@ -928,7 +928,7 @@ class TheBlockchainAPIResource:
         """
         response = self._request(
             payload=dict(),
-            endpoint=f"solana/nft/marketplaces/listing/{network}/{mint_address}",
+            endpoint=f"solana/nft/marketplaces/listing/{network.value}/{mint_address}",
             request_method=self.__RequestMethod.GET
         )
         if 'error_message' in response:
